@@ -295,59 +295,6 @@ def face_statement(
 as_reported_raw = face_statement
 
 
-def dimensional_raw(
-    company_identifiers=None,
-    metrics=[],
-    start_year=None,
-    start_period=None,
-    end_year=None,
-    end_period=None,
-    period_type="annual",
-):
-    """Segments and Breakouts
-
-    The data behind the breakouts/segment page, https://www.calcbench.com/breakout.
-
-    :param sequence company_identifiers: Tickers/CIK codes. eg. ['msft', 'goog', 'appl', '0000066740']
-    :param sequence metrics: list of dimension tuple strings, get the list @ https://www.calcbench.com/api/availableBreakouts, pass in the "databaseName"
-    :param int start_year: first year of data to get
-    :param int start_period: first period of data to get.  0 for annual data, 1, 2, 3, 4 for quarterly data.
-    :param int end_year: last year of data to get
-    :param int end_period: last period of data to get. 0 for annual data, 1, 2, 3, 4 for quarterly data.
-    :param str period_type: 'quarterly' or 'annual', only applicable when other period data not supplied.
-    :return: A list of points.  The points correspond to the lines @ https://www.calcbench.com/breakout.  For each requested metric there will be a the formatted value and the unformatted value denote bya  _effvalue suffix.  The label is the dimension label associated with the values.
-    :rtype: sequence
-
-    Usage::
-      >>> cb.dimensional_raw(company_identifiers=['fdx'], metrics=['OperatingSegmentRevenue'], start_year=2018)
-
-    """
-    if len(metrics) == 0:
-        raise (ValueError("Need to supply at least one breakout."))
-    if period_type not in ("annual", "quarterly"):
-        raise (ValueError("period_type must be in ('annual', 'quarterly')"))
-
-    payload = {
-        "companiesParameters": {
-            "entireUniverse": len(company_identifiers) == 0,
-            "companyIdentifiers": company_identifiers,
-        },
-        "periodParameters": {
-            "year": end_year or start_year,
-            "period": start_period,
-            "endYear": start_year,
-            "periodType": period_type,
-            "asOriginallyReported": False,
-        },
-        "pageParameters": {
-            "metrics": metrics,
-            "dimensionName": "Segment",
-            "AsOriginallyReported": False,
-        },
-    }
-    return _json_POST("dimensionalData", payload)
-
-
 def tag_contents(accession_id, block_tag_name):
     payload = {"accession_ids": accession_id, "block_tag_name": block_tag_name}
     json = _json_GET("query/disclosuresByTag", payload)
